@@ -242,20 +242,31 @@ def mysql_proc(request):
     mysql_executor = TCPCoordinatedExecutor(
         '''
             {mysql_server} --datadir={datadir} --pid-file={pidfile}
-            --port={port} --socket={socket}'''
-        .format(
+            --port={port} --socket={socket} --log-error={logfile}
+            --skip-syslog
+        '''.format(
             mysql_server=config.mysql.mysql_server,
             datadir=config.mysql.datadir,
             pidfile=config.mysql.pidfile,
             port=config.mysql.port,
             socket=config.mysql.socket,
+            logfile=config.mysql.logfile,
         ),
         host=config.mysql.host,
         port=config.mysql.port,
     )
     mysql_executor.start()
 
+    def shutdown_server():
+        return (
+            config.mysql.mysql_admin,
+            '--socket=%s' % config.mysql.socket,
+            '--user=%s' % config.mysql.user,
+            'shutdown'
+        )
+
     def stop_server_and_remove_directory():
+        subprocess.check_output(' '.join(shutdown_server()), shell=True)
         mysql_executor.stop()
         remove_mysql_directory(config)
 
@@ -295,7 +306,6 @@ def mysqldb(request, mysqldb_session):
     def drop_database():
         config = get_config(request)
         mysqldb_session.query('DROP DATABASE IF EXISTS %s' % config.mysql.db)
-        mysqldb_session.close()
 
     request.addfinalizer(drop_database)
 
